/*
** Module   : OsPropertiesDaemon.java
** Abstract : Client side daemon to handle Progress 4GL compatible OS properties nhandling.
**
** Copyright (c) 2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 EVL 20140325 Created initial version to inspect some system properties on the client side.
** 002 CA  20140715 Added getTempDirectory.
*/

package com.goldencode.p2j.util;

import java.io.*;
import com.goldencode.p2j.net.*;

/**
 * A client side class to manipulate with environments. The environment can be the INI file or
 * registry sections containing the keys.
 *
 * @author    EVL
 */
public class OsPropertiesDaemon
implements OperatingSystemInspector
{
   /** Token used to authenticate with the dispatcher when registering APIs. */
   private static Object modToken = null;
   
   /**
    * Create an instance and export its API to the network.
    *
    * @param    single
    *           <code>true</code> to startup within the server process which must bypass the
    *           shared infrastructure initialization. Use <code>false</code> for the normal
    *           client JVM startup.
    */
   public OsPropertiesDaemon(boolean single)
   {
      synchronized (OsPropertiesDaemon.class)
      {
         modToken = RemoteObject.registerServer(OperatingSystemInspector.class,
                                                this,
                                                modToken,
                                                single);
      }
   }
      
   /**
    * If there is still no match, then any <code>os.name</code> with the
    * lowercase text "unix" will return "UNIX" and any <code>os.name</code>
    * with the lowercase text "windows" will return "WIN32". 
    * <p>
    * If there is still no match, the <code>os.name</code> returned by the
    * Java will be returned. 
    *
    * @return   The name of the current operating system.
    */
   public String getOperatingSystem()
   {
      return System.getProperty("os.name").toLowerCase();
   }

   /**
    * Gets the path separator character used to parse the Progress search
    * path.
    * <p>
    * The value returned may have been found via a search algorithm that
    * is account (user or process) specific or group specific
    * within the current server or a global default for all servers. 
    * <p>
    * If no value is found via this lookup, then the default value of
    * ':' will be returned.
    *
    * @return   The path to Progress source files.
    */
   public String getPathSeparator()
   {
      return File.pathSeparator;
   }
   
   /**
    * Gets the name of the directory where temporary files are stored.
    * Corresponds with with the <code>SESSION:TEMP-DIRECTORY</code> system
    * handle attribute.
    * 
    * @return  Name of temporary directory.
    */
   public String getTempDirectory()
   {
      return System.getProperty("java.io.tmpdir");
   }
}
